@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2020 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -50,7 +50,6 @@ configurations = (
             "php",
             "cs",
             "java",
-            "kt",
             "css",
             "cpp",
             "c",
@@ -110,7 +109,9 @@ configurations = (
             "am",
             "m4",
             "md",
-            "csv"
+            "csv",
+            "kt",
+            "asm"
         ),
         "file_exclusion" : ("android-sdk",)
     }
